==> mule-metadata-model-java-1.3.0-20210622-test-sources.jar: org/mule/pojo/NumberTypes.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.pojo;

import java.math.BigDecimal;
import java.math.BigInteger;

public class NumberTypes {

  private short aShort;
  private Short aShortWrapper;

  private int anInt;
  private Integer anIntWrapper;

  private double aDouble;
  private Double aDoubleWrapper;

  private float aFloat;
  private Float aFloatWrapper;

  private Long aLongWrapper;
  private long aLong;

  private BigInteger bigInteger;
  private BigDecimal bigDecimal;

  public short getaShort() {
    return aShort;
  }

  public void setaShort(short aShort) {
    this.aShort = aShort;
  }

  public Short getaShortWrapper() {
    return aShortWrapper;
  }

  public void setaShortWrapper(Short aShortWrapper) {
    this.aShortWrapper = aShortWrapper;
  }

  public int getAnInt() {
    return anInt;
  }

  public void setAnInt(int anInt) {
    this.anInt = anInt;
  }

  public Integer getAnIntWrapper() {
    return anIntWrapper;
  }

  public void setAnIntWrapper(Integer anIntWrapper) {
    this.anIntWrapper = anIntWrapper;
  }

  public double getaDouble() {
    return aDouble;
  }

  public void setaDouble(double aDouble) {
    this.aDouble = aDouble;
  }

  public Double getaDoubleWrapper() {
    return aDoubleWrapper;
  }

  public void setaDoubleWrapper(Double aDoubleWrapper) {
    this.aDoubleWrapper = aDoubleWrapper;
  }

  public float getaFloat() {
    return aFloat;
  }

  public void setaFloat(float aFloat) {
    this.aFloat = aFloat;
  }

  public Float getaFloatWrapper() {
    return aFloatWrapper;
  }

  public void setaFloatWrapper(Float aFloatWrapper) {
    this.aFloatWrapper = aFloatWrapper;
  }

  public Long getaLongWrapper() {
    return aLongWrapper;
  }

  public void setaLongWrapper(Long aLongWrapper) {
    this.aLongWrapper = aLongWrapper;
  }

  public long getaLong() {
    return aLong;
  }

  public void setaLong(long aLong) {
    this.aLong = aLong;
  }

  public BigInteger getBigInteger() {
    return bigInteger;
  }

  public void setBigInteger(BigInteger bigInteger) {
    this.bigInteger = bigInteger;
  }

  public BigDecimal getBigDecimal() {
    return bigDecimal;
  }

  public void setBigDecimal(BigDecimal bigDecimal) {
    this.bigDecimal = bigDecimal;
  }
}

==> mule-metadata-model-java-1.4.0-test-sources.jar: org/mule/pojo/NumberTypes.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.pojo;

import java.math.BigDecimal;
import java.math.BigInteger;

public class NumberTypes {

  private short aShort;
  private Short aShortWrapper;

  private int anInt;
  private Integer anIntWrapper;

  private double aDouble;
  private Double aDoubleWrapper;

  private float aFloat;
  private Float aFloatWrapper;

  private Long aLongWrapper;
  private long aLong;

  private BigInteger bigInteger;
  private BigDecimal bigDecimal;

  private byte aByte;
  private Byte aByteWrapper;

  public short getaShort() {
    return aShort;
  }

  public void setaShort(short aShort) {
    this.aShort = aShort;
  }

  public Short getaShortWrapper() {
    return aShortWrapper;
  }

  public void setaShortWrapper(Short aShortWrapper) {
    this.aShortWrapper = aShortWrapper;
  }

  public int getAnInt() {
    return anInt;
  }

  public void setAnInt(int anInt) {
    this.anInt = anInt;
  }

  public Integer getAnIntWrapper() {
    return anIntWrapper;
  }

  public void setAnIntWrapper(Integer anIntWrapper) {
    this.anIntWrapper = anIntWrapper;
  }

  public double getaDouble() {
    return aDouble;
  }

  public void setaDouble(double aDouble) {
    this.aDouble = aDouble;
  }

  public Double getaDoubleWrapper() {
    return aDoubleWrapper;
  }

  public void setaDoubleWrapper(Double aDoubleWrapper) {
    this.aDoubleWrapper = aDoubleWrapper;
  }

  public float getaFloat() {
    return aFloat;
  }

  public void setaFloat(float aFloat) {
    this.aFloat = aFloat;
  }

  public Float getaFloatWrapper() {
    return aFloatWrapper;
  }

  public void setaFloatWrapper(Float aFloatWrapper) {
    this.aFloatWrapper = aFloatWrapper;
  }

  public Long getaLongWrapper() {
    return aLongWrapper;
  }

  public void setaLongWrapper(Long aLongWrapper) {
    this.aLongWrapper = aLongWrapper;
  }

  public long getaLong() {
    return aLong;
  }

  public void setaLong(long aLong) {
    this.aLong = aLong;
  }

  public BigInteger getBigInteger() {
    return bigInteger;
  }

  public void setBigInteger(BigInteger bigInteger) {
    this.bigInteger = bigInteger;
  }

  public BigDecimal getBigDecimal() {
    return bigDecimal;
  }

  public void setBigDecimal(BigDecimal bigDecimal) {
    this.bigDecimal = bigDecimal;
  }

  public byte getaByte() {
    return aByte;
  }

  public void setaByte(byte aByte) {
    this.aByte = aByte;
  }

  public Byte getaByteWrapper() {
    return aByteWrapper;
  }

  public void setaByteWrapper(Byte aByteWrapper) {
    this.aByteWrapper = aByteWrapper;
  }
}
